<?php

namespace Survey\Transferform\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Transferform\Models\Transferform;

class TransferformPolicy
{

    /**
     * Determine if the given user can view the transferform.
     *
     * @param UserPolicy $user
     * @param Transferform $transferform
     *
     * @return bool
     */
    public function view(UserPolicy $user, Transferform $transferform)
    {
        if ($user->canDo('transferform.transferform.view') && $user->isAdmin()) {
            return true;
        }

        return $transferform->user_id == user_id() && $transferform->user_type == user_type();
    }

    /**
     * Determine if the given user can create a transferform.
     *
     * @param UserPolicy $user
     * @param Transferform $transferform
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('transferform.transferform.create');
    }

    /**
     * Determine if the given user can update the given transferform.
     *
     * @param UserPolicy $user
     * @param Transferform $transferform
     *
     * @return bool
     */
    public function update(UserPolicy $user, Transferform $transferform)
    {
        if ($user->canDo('transferform.transferform.edit') && $user->isAdmin()) {
            return true;
        }

        return $transferform->user_id == user_id() && $transferform->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given transferform.
     *
     * @param UserPolicy $user
     * @param Transferform $transferform
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Transferform $transferform)
    {
        return $transferform->user_id == user_id() && $transferform->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given transferform.
     *
     * @param UserPolicy $user
     * @param Transferform $transferform
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Transferform $transferform)
    {
        if ($user->canDo('transferform.transferform.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given transferform.
     *
     * @param UserPolicy $user
     * @param Transferform $transferform
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Transferform $transferform)
    {
        if ($user->canDo('transferform.transferform.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
